create_ml_data: Data divider for machine learning

Description Usage Arguments Value Examples

View source: R/create_ml_data.R

Description

'create_ml_data()'

Usage

1
2
create_ml_data(df, proportion = c(0.8, 0, 0.2), validation = FALSE,
  seed_val = 1537)

Arguments

df

a data.frame object

proportion

the proportion to allocate to training, test and validation. Default split is training 0.8, test 0.2 and validation 0

validation

whether to include a validation split to the data

seed_val

set the seed value for reproducibility default 1537

Value

Returs up to 3 different data sets straight into global environment

Examples

1

aBoyNamedKerry/beisml documentation built on Oct. 31, 2019, 1:52 a.m.