rescale_data: Rescale numeric data by standardising or normalising as...

Description Usage Arguments Value Examples

View source: R/rescale_data.R

Description

Rescale numeric data by standardising or normalising as appropriate

Usage

1
rescale_data(df, scale = c("standardise", "normalise"))

Arguments

df

a data.frame object

scale

Choose type of recaling, default is to 'standardise' so rescale using the standard deviation. choosing 'normalise' will scale the data in range [0,1] and therefore outliers will be less relavnt.

Value

A data frame where numeric data has been rescaled

Examples

1
rescale_data(df = mtcars, scale = "standardise")

aBoyNamedKerry/beisml documentation built on Oct. 31, 2019, 1:52 a.m.