Description Usage Arguments Value Examples
View source: R/create_ml_data.R
'create_ml_data()'
1 2 | create_ml_data(df, proportion = c(0.8, 0, 0.2), validation = FALSE,
seed_val = 1537)
|
df |
a data.frame object |
proportion |
the proportion to allocate to training, test and validation. Default split is training 0.8, test 0.2 and validation 0 |
validation |
whether to include a validation split to the data |
seed_val |
set the seed value for reproducibility default 1537 |
Returs up to 3 different data sets straight into global environment
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.