Description Usage Arguments Value Examples
Rescale numeric data by standardising or normalising as appropriate
1 | rescale_data(df, scale = c("standardise", "normalise"))
|
df |
a data.frame object |
scale |
Choose type of recaling, default is to 'standardise' so rescale using the standard deviation. choosing 'normalise' will scale the data in range [0,1] and therefore outliers will be less relavnt. |
A data frame where numeric data has been rescaled
1 | rescale_data(df = mtcars, scale = "standardise")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.